Index: public/fpdfview.h |
diff --git a/public/fpdfview.h b/public/fpdfview.h |
index 469053c4e8479debec7affb871d8bf5f796bfdc4..4d868ae01ecde698ceb02a213da90ec398a7e764 100644 |
--- a/public/fpdfview.h |
+++ b/public/fpdfview.h |
@@ -594,11 +594,11 @@ DLLEXPORT void STDCALL FPDF_RenderPage(HDC dc, |
// 1 (rotated 90 degrees clockwise) |
// 2 (rotated 180 degrees) |
// 3 (rotated 90 degrees counter-clockwise) |
// flags - 0 for normal display, or combination of flags |
// defined above. With FPDF_ANNOT flag, it renders all |
// annotations that does not require user-interaction, |
// which are all annotations except widget and popup |
// annotations. |
// Return value: |
// None. |
DLLEXPORT void STDCALL FPDF_RenderPageBitmap(FPDF_BITMAP bitmap, |
@@ -610,6 +610,28 @@ DLLEXPORT void STDCALL FPDF_RenderPageBitmap(FPDF_BITMAP bitmap, |
int rotate, |
int flags); |
+// Function: FPDF_RenderPageBitmapWithMatrix |
+// Render contents of a page to a device independent bitmap. |
+// Parameters: |
+// bitmap - Handle to the device independent bitmap (as the |
+// output buffer). The bitmap handle can be created |
+// by FPDFBitmap_Create. |
+// page - Handle to the page. Returned by FPDF_LoadPage |
+// matrix - The transform matrix. |
+// clipping - The rect to clip to. |
+// flags - 0 for normal display, or combination of the Page |
+// Rendering flags defined above. With the FPDF_ANNOT |
+// flag, it renders all annotations that do not require |
+// user-interaction, which are all annotations except |
+// widget and popup annotations. |
+// Return value: |
+// None. |
+DLLEXPORT void STDCALL FPDF_RenderPageBitmapWithMatrix(FPDF_BITMAP bitmap, |
+ FPDF_PAGE page, |
+ const FS_MATRIX* matrix, |
+ const FS_RECTF* clipping, |
+ int flags); |
+ |
#ifdef _SKIA_SUPPORT_ |
DLLEXPORT FPDF_RECORDER STDCALL FPDF_RenderPageSkp(FPDF_PAGE page, |
int size_x, |
@@ -594,11 +594,11 @@ DLLEXPORT void STDCALL FPDF_RenderPage(HDC dc, |
// 2 (rotated 180 degrees) |
// 3 (rotated 90 degrees counter-clockwise) |
-// flags - 0 for normal display, or combination of flags |
-// defined above. With FPDF_ANNOT flag, it renders all |
-// annotations that does not require user-interaction, |
-// which are all annotations except widget and popup |
-// annotations. |
+// flags - 0 for normal display, or combination of the Page |
+// Rendering flags defined above. With the FPDF_ANNOT |
+// flag, it renders all annotations that do not require |
+// user-interaction, which are all annotations except |
+// widget and popup annotations. |
// Return value: |
// None. |